%global gettext_package gst-mixer-2.0

Summary:        Legacy gnome-volume-control for advanced use cases
Name:           gst-mixer
Version:        2.26.0
Release:        3%{?dist}
License:        GPLv2+ and GFDL
Group:          Applications/Multimedia
Source:         http://download.gnome.org/sources/gnome-media/2.26/gnome-media-%{version}.tar.bz2
# Renames the app from 'gnome-volume-control' to 'gst-mixer'
Patch0:         gst-mixer-2.26.0-rebrand.patch
# Fixes Launchpad bug #345645 (patch from that report / upstream)
Patch1:         gst-mixer-2.26.0-switch.patch
Patch2:         gst-mixer-2.26.0-help-uri.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
URL:            http://www.gnome.org
ExcludeArch:    s390 s390x

Requires(post): scrollkeeper >= 0.1.4
Requires(postun): scrollkeeper >= 0.1.4
Requires(post): GConf2 >= 2.14
Requires(pre): GConf2 >= 2.14
Requires(preun): GConf2 >= 2.14

BuildRequires:  gtk2-devel >= 2.10.0
BuildRequires:  libgnome-devel >= 2.13.7
BuildRequires:  libgnomeui-devel >= 2.13.2
BuildRequires:  libglade2-devel
BuildRequires:  GConf2-devel
BuildRequires:  gstreamer-devel >= 0.10.3
BuildRequires:  gstreamer-plugins-base-devel >= 0.10.3
BuildRequires:  dbus-glib-devel
BuildRequires:  libcanberra-devel
BuildRequires:  gnome-doc-utils
BuildRequires:  intltool
BuildRequires:  unique-devel
BuildRequires:  desktop-file-utils
# for patch 0
BuildRequires:  autoconf automake libtool

#For stuff dropped from this 'alternate' package
Requires:       gnome-media

%description
This package contains the pre-GNOME 2.26 version of the GNOME
volume control application, renamed 'gst-mixer' (the name it carries
in the source tree). It is provided to cover use cases the new
GNOME volume control application cannot handle.

%prep
%setup -q -n gnome-media-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

mv gst-mixer/gnome-volume-control.desktop.in.in gst-mixer/gst-mixer.desktop.in.in
mv gst-mixer/gnome-volume-control.schemas.in gst-mixer/gst-mixer.schemas.in
mv gst-mixer/doc/gnome-volume-control.omf.in gst-mixer/doc/gst-mixer.omf.in
mv gst-mixer/doc/C/gnome-volume-control.xml gst-mixer/doc/C/gst-mixer.xml

autoreconf -f -i

%build
# try to work around a problem where gst-inspect does
# not find playbin the first time around
DBUS_FATAL_WARNINGS=0 /usr/bin/gst-inspect-0.10 --print-all > /dev/null
%configure --disable-schemas-install --enable-gnomecd=no --enable-cddbslave=no --enable-gstmix --disable-pulseaudio --disable-grecord --disable-esound --disable-gstprops --disable-profiles
make #%{?_smp_mflags}

# strip unneeded translations from .mo files
# ideally intltool (ha!) would do that for us
# http://bugzilla.gnome.org/show_bug.cgi?id=474987
cd po
grep -v ".*[.]desktop[.]in[.]in$\|.*[.]server[.]in[.]in$" POTFILES.in > POTFILES.keep
mv POTFILES.keep POTFILES.in
intltool-update --pot
for p in *.po; do
  msgmerge $p %{gettext_package}.pot > $p.out
  msgfmt -o `basename $p .po`.gmo $p.out
done

%install
rm -rf $RPM_BUILD_ROOT

make install DESTDIR=$RPM_BUILD_ROOT

rm -rf $RPM_BUILD_ROOT%{_libdir}/lib*.*a
rm -rf $RPM_BUILD_ROOT%{_libdir}/libglade/2.0/lib*.*a
rm -rf $RPM_BUILD_ROOT/var/scrollkeeper

# We don't want all this in this 'alternative' package: we'll
# require gnome-media (see above) to let the 'master' package
# provide it
rm -rf $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/16x16/status
rm -rf $RPM_BUILD_ROOT%{_datadir}/gnome-media/sounds
rm -rf $RPM_BUILD_ROOT%{_datadir}/sounds

# save space by linking identical images in translated docs
for helpdir in $RPM_BUILD_ROOT%{_datadir}/gnome/help/*; do
  for f in $helpdir/C/figures/*.png; do
    b="$(basename $f)"
    for d in $helpdir/*; do
      if [ -d "$d" -a "$d" != "$helpdir/C" ]; then
        g="$d/figures/$b"
        if [ -f "$g" ]; then
          if cmp -s $f $g; then
            rm "$g"; ln -s "../../C/figures/$b" "$g"
          fi
        fi
      fi
    done
  done
done

%find_lang %{gettext_package} --all-name --with-gnome

desktop-file-install \
  --add-category=Mixer \
  --dir=$RPM_BUILD_ROOT/%{_datadir}/applications \
  $RPM_BUILD_ROOT/%{_datadir}/applications/%{name}.desktop

%clean
rm -rf $RPM_BUILD_ROOT

%post
scrollkeeper-update -q -o %{_datadir}/omf/%{name} || :
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule \
    %{_sysconfdir}/gconf/schemas/gst-mixer.schemas \
    > /dev/null || :
touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :

%pre
if [ "$1" -gt 1 ]; then
  export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
  if [ -f %{_sysconfdir}/gconf/schemas/gst-mixer.schemas ] ; then
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/gst-mixer.schemas \
      > /dev/null || :
  fi
fi

%preun
if [ "$1" -eq 0 ]; then
  export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
  if [ -f %{_sysconfdir}/gconf/schemas/gst-mixer.schemas ] ; then
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/gst-mixer.schemas \
      > /dev/null || :
  fi
fi

%postun
scrollkeeper-update -q || :
touch --no-create %{_datadir}/icons/hicolor || :
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :

%files  -f %{gettext_package}.lang
%defattr(-, root, root)

%doc AUTHORS COPYING NEWS README
%{_sysconfdir}/gconf/schemas/gst-mixer.schemas
%{_datadir}/icons/hicolor/16x16/devices/*
%{_datadir}/gnome-media/pixmaps
%{_datadir}/applications/*
%{_bindir}/*

%changelog
* Sun Jul 19 2009 Christoph Wickert <cwickert@fedoraproject.org> - 2.26.0-3
- Fix 'Help' button (#508531)
- Add category 'Mixer' to menu enty for nested menus in multimedia-menus

* Fri May 1 2009 Adam Williamson <awilliam@redhat.com> - 2.26.0-2
- Drop a bunch of %%defines in the spec as recommended for review

* Tue Apr 28 2009 Adam Williamson <awilliam@redhat.com> - 2.26.0-1
- Initial Fedora package based on gnome-media spec

